# ------------------------------------------------------------------
# Copyright (c) 2024 PyInstaller Development Team.
#
# This file is distributed under the terms of the GNU General Public
# License (version 2.0 or later).
#
# The full license is available in LICENSE, distributed with
# this software.
#
# SPDX-License-Identifier: GPL-2.0-or-later
# ------------------------------------------------------------------

hiddenimports = [
    'cgi',
    'falcon.app_helpers',
    'falcon.forwarded',
    'falcon.media',
    'falcon.request_helpers',
    'falcon.responders',
    'falcon.response_helpers',
    'falcon.routing',
    'falcon.vendor.mimeparse',
    'falcon.vendor',
    'uuid',
    'xml.etree.ElementTree',
    'xml.etree'
]
